@@ -1,15 +1,7 @@
-#!/usr/bin/env python
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-
-import sys
-import os
-DIR = os.path.abspath(os.path.normpath(os.path.join(__file__,
-    '..', '..', '..', '..', '..', 'trytond')))
-if os.path.isdir(DIR):
-    sys.path.insert(0, os.path.dirname(DIR))
-
 import unittest
+import doctest
 import datetime
 from decimal import Decimal
 import trytond.tests.test_tryton
@@ -19,15 +11,14 @@ from trytond.transaction import Transaction
 
 
 class StockSupplyDayTestCase(unittest.TestCase):
-    '''
-    Test StockSupplyDay module.
-    '''
+    'Test StockSupplyDay module'
 
     def setUp(self):
         trytond.tests.test_tryton.install_module('stock_supply_day')
         self.uom = POOL.get('product.uom')
         self.uom_category = POOL.get('product.uom.category')
         self.category = POOL.get('product.category')
+        self.template = POOL.get('product.template')
         self.product = POOL.get('product.product')
         self.company = POOL.get('company.company')
         self.party = POOL.get('party.party')
@@ -37,21 +28,15 @@ class StockSupplyDayTestCase(unittest.TestCase):
         self.user = POOL.get('res.user')
 
     def test0005views(self):
-        '''
-        Test views.
-        '''
+        'Test views'
         test_view('stock_supply_day')
 
     def test0006depends(self):
-        '''
-        Test depends.
-        '''
+        'Test depends'
         test_depends()
 
     def test0010compute_supply_date(self):
-        '''
-        Test compute_supply_date.
-        '''
+        'Test compute_supply_date'
         dates = [
             # purchase date, delivery time, weekday, supply date
             (datetime.date(2011, 11, 21), 10, 0, datetime.date(2011, 12, 5)),
@@ -77,9 +62,7 @@ class StockSupplyDayTestCase(unittest.TestCase):
                 self.assertEqual(date, supply_date)
 
     def test0020compute_purchase_date(self):
-        '''
-        Test compute_purchase_date.
-        '''
+        'Test compute_purchase_date'
         dates = [
             # purchase date, delivery time, weekday, supply date
             (datetime.date(2011, 11, 25), 10, 0, datetime.date(2011, 12, 6)),
@@ -109,24 +92,29 @@ class StockSupplyDayTestCase(unittest.TestCase):
         :param weekday: supply day of the week (0 - 6)
         :return: the id of the Product Supplier Day
         '''
-        uom_category = self.uom_category.create({'name': 'Test'})
-        uom = self.uom.create({
-            'name': 'Test',
-            'symbol': 'T',
-            'category': uom_category.id,
-            'rate': 1.0,
-            'factor': 1.0,
-            })
-        category = self.category.create({'name': 'ProdCategoryTest'})
-        product = self.product.create({
-                'name': 'ProductTest',
-                'default_uom': uom.id,
-                'category': category.id,
-                'account_category': True,
-                'list_price': Decimal(0),
-                'cost_price': Decimal(0),
-                })
-        company, = self.company.search([('name', '=', 'B2CK')])
+        uom_category, = self.uom_category.create([{'name': 'Test'}])
+        uom, = self.uom.create([{
+                    'name': 'Test',
+                    'symbol': 'T',
+                    'category': uom_category.id,
+                    'rate': 1.0,
+                    'factor': 1.0,
+                    }])
+        category, = self.category.create([{'name': 'ProdCategoryTest'}])
+        template, = self.template.create([{
+                    'name': 'ProductTest',
+                    'default_uom': uom.id,
+                    'category': category.id,
+                    'account_category': True,
+                    'list_price': Decimal(0),
+                    'cost_price': Decimal(0),
+                    }])
+        product, = self.product.create([{
+                    'template': template.id,
+                    }])
+        company, = self.company.search([
+                ('rec_name', '=', 'Dunder Mifflin'),
+                ])
         self.user.write([self.user(USER)], {
             'main_company': company.id,
             'company': company.id,
@@ -139,22 +127,22 @@ class StockSupplyDayTestCase(unittest.TestCase):
             ('kind', '=', 'payable'),
             ('company', '=', company.id),
             ])
-        supplier = self.party.create({
-            'name': 'supplier',
-            'account_receivable': receivable.id,
-            'account_payable': payable.id,
-            })
-        product_supplier = self.product_supplier.create({
-            'product': product.id,
-            'company': company.id,
-            'party': supplier.id,
-            'delivery_time': delivery_time,
-            })
+        supplier, = self.party.create([{
+                    'name': 'supplier',
+                    'account_receivable': receivable.id,
+                    'account_payable': payable.id,
+                    }])
+        product_supplier, = self.product_supplier.create([{
+                    'product': template.id,
+                    'company': company.id,
+                    'party': supplier.id,
+                    'delivery_time': delivery_time,
+                    }])
         if weekday is not None:
-            self.product_supplier_day.create({
-                'product_supplier': product_supplier.id,
-                'weekday': str(weekday),
-                })
+            self.product_supplier_day.create([{
+                        'product_supplier': product_supplier.id,
+                        'weekday': str(weekday),
+                        }])
         return product_supplier
 
 
@@ -162,15 +150,12 @@ def suite():
     suite = trytond.tests.test_tryton.suite()
     from trytond.modules.company.tests import test_company
     for test in test_company.suite():
-        if test not in suite:
+        if test not in suite and not isinstance(test, doctest.DocTestCase):
             suite.addTest(test)
     from trytond.modules.account.tests import test_account
     for test in test_account.suite():
-        if test not in suite:
+        if test not in suite and not isinstance(test, doctest.DocTestCase):
             suite.addTest(test)
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
         StockSupplyDayTestCase))
     return suite
-
-if __name__ == '__main__':
-    unittest.TextTestRunner(verbosity=2).run(suite())
